Learn R Programming

AdaptGauss (version 1.2.0)

BayesDecisionBoundaries: Decision Boundaries calculated through Bayes Theorem

Description

Function finds the intersections of Gaussians or LogNormals

Usage

BayesDecisionBoundaries(Means,SDs,Weights,IsLogDistribution,MinData,MaxData,Ycoor)

Arguments

Means
vector[1:L] of Means of Gaussians (of GMM)
SDs
vector of standard deviations, estimated Gaussian Kernels, has to be the same length as Means
Weights
vector of relative number of points in Gaussians (prior probabilities), has to be the same length as Means
IsLogDistribution
Optional, ==1 if distribution(i) is a LogNormal, default vector of zeros of length 1:L
MinData
Optional, Beginning of range, where the Boundaries are searched for, default min(M)
MaxData
Optional, End of range, where the Boundaries are searched for, default max(M)
Ycoor
Optional, Bool, if TRUE instead of vector of DecisionBoundaries list of DecisionBoundaries and DBY is returned

Value

  • DecisionBoundariesvector[1:L-1], Bayes decision boundaries
  • DBYif (Ycoor==TRUE), y values at the cross points of the Gaussians is also returned, that the return is a list of DecisionBoundaries and DBY

References

Duda, R. O., Hart, P. E., & Stork, D. G. (2001). Pattern classification. 2nd. Edition. New York, p. 512ff

See Also

AdaptGauss,Intersect2Mixtures,Bayes4Mixtures