Learn R Programming

AdaptGauss (version 1.2.0)

InformationCriteria4GMM: Information Criteria For GMM

Description

Calculates the AIC and BIC criteria

Usage

InformationCriteria4GMM(Data, Means, SDs, Weights, IsLogDistribution)

Arguments

Data
vector (1:N) of data points
Means
vector[1:L] of Means of Gaussians (of GMM),L == Number of Gaussians
SDs
vector of standard deviations, estimated Gaussian Kernels, has to be the same length as Means
Weights
vector of relative number of points in Gaussians (prior probabilities), has to be the same length as Means
IsLogDistribution
Optional, ==1 if distribution(i) is a LogNormal, default vector of zeros of length L, LogNormal Modes are at this point only experimental

Value

  • List with
  • KNumber of gaussian mixtures
  • AICAkaike Informations criterium
  • BICBayes Information criterium
  • LogLikelihoodLogLikelihood of GMM, see LogLikelihood4Mixtures
  • PDFmixtureprobability density function of GMM, see Pdf4Mixtures
  • LogPDFdatalog(PDFmixture)

Details

AIC = 2*k -2*LogLikelihood, k = nr. of model parameter = 3*Nr. of Gaussians One Gaussian: K=2 (Weight is then not an parameter!) SMALL SAMPLE CORRECTION: for n= nr of Data and n < 40 * k, AIC is adjusted to AIC=AIC+ (2*k*(k+1))/(n-k-1) BIC = k* log(n) - 2*LogLikelihood Only for a Gaussian Mixture Model (GMM) verified, for the Log Gaussian, Gaussian, Log Gaussian (LGL) Model only experimental

References

Aho, K., Derryberry, D., & Peterson, T. (2014). Model selection for ecologists: the worldviews of AIC and BIC. Ecology, 95(3), 631-636.