Learn R Programming

AdaptGauss (version 1.2.0)

LikelihoodRatio4Mixtures: Likelihood Ratio for Gaussian Mixtures

Description

Computes the likelihood ratio for two Gaussian Mixture Models.

Usage

LikelihoodRatio4Mixtures(Data,NullMixture,OneMixture,PlotIt,LowerLimit,UpperLimit)

Arguments

Data
Data points.
NullMixture
A Matrix: cbind(Means0,SDs0,Weights0) or cbind(Means0,SDs0,Weights0,IsLog0). The null model; usually with less Gaussians than the OneMixture
OneMixture
A Matrix: cbind(Means1,SDs1,Weights1) or cbind(Means1,SDs1,Weights1,IsLog1). The alternative model usually with more Gaussians than the OneMixture.
PlotIt
Optional: zero or one. o a Plot of the compared cdf's and the KS-test distribution (Diff)
LowerLimit
Optional: test only for Data >= LowerLimit, Default = min(Data) i.e all Data.
UpperLimit
Optional: test only for Data

Value

  • List with
  • Pvaluethe error that we make, if we accept OneMixture as the better Model over the NullMixture
  • NullLogLikelihoodlog likelihood of GMM Null
  • OneLogLikelihoodlog likelihood of GMM One