Arguments
Means
vector[1:L] of Means of Gaussians (of GMM)
SDs
vector of standard deviations, estimated Gaussian Kernels, has to be the same length as Means
Weights
vector of relative number of points in Gaussians (prior probabilities), has to be the same length as Means
IsLogDistribution
Optional, ==1 if distribution(i) is a LogNormal, default vector of zeros of length 1:L
MinData
Optional, Beginning of range, where the Boundaries are searched for, default min(M)
MaxData
Optional, End of range, where the Boundaries are searched for, default max(M)
Ycoor
Optional, Bool, if TRUE instead of vector of DecisionBoundaries
list of DecisionBoundaries and DBY is returned